<?php
/**
 * Hilfsfunktionen
 *
 * @author        Christian Lang
 * @version        1.0
 * @category    floating-bar
 */

if ( ! function_exists( 'dt_floating_bar_visible' ) ) {
    /**
     * dt_floating_bar_visible function.
     *
     * @param string $type (default: post)
     *
     * @return boolean
     */
    function dt_floating_bar_visible ( $type = 'post' )
    {
        $show_at = get_field( 'floating_bar_show_at', 'options' );

        if ( is_array( $show_at ) ) {
            if ( in_array( $type, $show_at ) ) {
                return true;
            }
        }

        return false;
    }
}

if ( ! function_exists( 'dt_floating_bar_show_after' ) ) {
    /**
     * dt_floating_bar_show_after function.
     *
     * @return int
     */
    function dt_floating_bar_show_after ()
    {
        $show_at = 25;

        if ( dt_phone_detect() ) {
            $show_at = get_field( 'floating_bar_show_after_smartphone', 'options' );
        } elseif ( dt_tablet_detect() ) {
            $show_at = get_field( 'floating_bar_show_after_tablet', 'options' );
        } else {
            $show_at = get_field( 'floating_bar_show_after_desktop', 'options' );
        }

        return $show_at;
    }
}

if ( ! function_exists( 'dt_floating_bar_profile' ) ) {
    /**
     * dt_floating_bar_profile function.
     *
     * @return int
     */
    function dt_floating_bar_profile ()
    {
        $profile_type = get_field( 'floating_bar_profile', 'options' );

        if ( $profile_type == 'random' ) {
            $args = array(
                'post_type'      => 'profile',
                'posts_per_page' => 1,
                'orderby'        => 'rand',
                'fields'         => 'ids',
                'meta_query'     => array()
            );

            $gender      = ( get_field( 'floating_bar_profile_gender', 'options' ) ? get_field( 'floating_bar_profile_gender', 'options' ) : '' );
            $age_from    = ( get_field( 'floating_bar_profile_age_from', 'options' ) ? get_field( 'floating_bar_profile_age_from', 'options' ) : '' );
            $age_to      = ( get_field( 'floating_bar_profile_age_to', 'options' ) ? get_field( 'floating_bar_profile_age_to', 'options' ) : '' );
            $figure      = ( get_field( 'floating_bar_profile_figure', 'options' ) ? get_field( 'floating_bar_profile_figure', 'options' ) : '' );
            $hair_color  = ( get_field( 'floating_bar_profile_hair_color', 'options' ) ? get_field( 'floating_bar_profile_hair_color', 'options' ) : '' );
            $weight_from = ( get_field( 'floating_bar_profile_weight_from', 'options' ) ? get_field( 'floating_bar_profile_weight_from', 'options' ) : '' );
            $weight_to   = ( get_field( 'floating_bar_profile_weight_to', 'options' ) ? get_field( 'floating_bar_profile_weight_to', 'options' ) : '' );
            $size_from   = ( get_field( 'floating_bar_profile_size_from', 'options' ) ? get_field( 'floating_bar_profile_size_from', 'options' ) : '' );
            $size_to     = ( get_field( 'floating_bar_profile_size_to', 'options' ) ? get_field( 'floating_bar_profile_size_to', 'options' ) : '' );

            /*
             * Geschlecht
             */
            if ( $gender ) {
                $args['meta_query'][] = array(
                    array(
                        'key'   => 'profile_gender',
                        'value' => $gender
                    )
                );
            }

            /*
            * Alter
            */
            if ( $age_from || $age_to ) {
                if ( $age_from == '' ) {
                    $age_from = '0';
                }

                if ( $age_to == '' ) {
                    $age_to = '999';
                }

                $args['meta_query'][] = array(
                    array(
                        'key'     => 'profile_age',
                        'value'   => array( $age_from, $age_to ),
                        'compare' => 'BETWEEN',
                        'type'    => 'NUMERIC'
                    )
                );
            }

            /*
             * Figur
             */
            if ( $figure ) {
                $args['meta_query'][] = array(
                    array(
                        'key'   => 'profile_figure',
                        'value' => $figure
                    )
                );
            }

            /*
             * Haarfarbe
             */
            if ( $hair_color ) {
                $args['meta_query'][] = array(
                    array(
                        'key'   => 'profile_hair_color',
                        'value' => $hair_color
                    )
                );
            }

            /*
            * Gewicht
            */
            if ( $weight_from || $weight_to ) {
                if ( $weight_from == '' ) {
                    $weight_from = '0';
                }

                if ( $weight_to == '' ) {
                    $weight_to = '999';
                }

                $args['meta_query'][] = array(
                    array(
                        'key'     => 'profile_weight',
                        'value'   => array( $weight_from, $weight_to ),
                        'compare' => 'BETWEEN',
                        'type'    => 'NUMERIC'
                    )
                );
            }

            /*
            * Größe
            */
            if ( $size_from || $size_to ) {
                if ( $size_from == '' ) {
                    $size_from = '0';
                }

                if ( $size_to == '' ) {
                    $size_to = '999';
                }

                $args['meta_query'][] = array(
                    array(
                        'key'     => 'profile_size',
                        'value'   => array( $size_from, $size_to ),
                        'compare' => 'BETWEEN',
                        'type'    => 'NUMERIC'
                    )
                );
            }

            $profile = get_posts( $args );

            if ( $profile ) {
                return $profile[0];
            }
        }

        if ( $profile_type == 'relation' ) {
            $profile = get_field( 'floating_bar_profile_relation', 'options' );

            if ( $profile ) {
                return $profile;
            }
        }

        return false;
    }
}

if ( ! function_exists( 'dt_floating_bar_get_form' ) ) {
    /**
     * dt_floating_bar_get_form function.
     *
     * @return string
     */
    function dt_floating_bar_get_form ()
    {
        ob_start();
        $network = dt_get_network();
        get_template_part( 'parts/forms/' . $network . '/form', 'floating-bar' );
        $output = ob_get_contents();
        ob_end_clean();

        return $output;
    }
}

if ( ! function_exists( 'dt_floating_bar_frontend' ) ) {
    /**
     * dt_floating_bar_frontend function.
     *
     */
    add_action( 'wp_footer', 'dt_floating_bar_frontend' );
    function dt_floating_bar_frontend ()
    {
        $active = get_field( 'floating_bar_active', 'options' );
        if ( ! $active ) {
            return;
        }

        $type    = get_post_type();
        $visible = dt_floating_bar_visible( $type );
        if ( ! $visible ) {
            return;
        }

        $profile_id = dt_floating_bar_profile();
        if ( ! $profile_id ) {
            return;
        }

        $profile    = new Profile( $profile_id );
        $show_after = dt_floating_bar_show_after();

        $html = '<div class="profile-floating-bar" data-show-at="' . $show_after . '">';
        $html .= '<div class="contact"  data-contact="' . $profile_id . '">';
        $html .= '<div class="container">';
        $html .= '<div class="inner">';
        $html .= '<div class="row">';
        $html .= '<div class="col-sm-4">';
        $html .= '<div class="media">';
        $html .= '<div class="media-left">';
        $html .= $profile->getImage( 'media' ) . dt_profile_get_status();
        $html .= '</div>';
        $html .= '<div class="media-body">';
        $html .= '<p class="h4">';
        $html .= '<span class="contact-name">' . $profile->getName() . ( $profile->getAge() ? '(' . $profile->getAge() . ')' : '' ) . '</span>';

        if ( $city = $profile->getCityLinked() ) {
            $html .= sprintf( __( '<br><span class="contact-text">sucht in</span> <span class="contact-city">%s</span>', 'datingtheme' ), $city );
        }
        $html .= '</p>';
        $html .= '</div>';
        $html .= '</div>';
        $html .= '</div>';
        $html .= '<div class="col-sm-8">';
        $html .= dt_floating_bar_get_form();
        $html .= '</div>';
        $html .= '</div>';
        $html .= '</div>';
        $html .= '</div>';
        $html .= '</div>';
        $html .= '</div>';

        echo apply_filters( 'dt_floating_bar_output', $html );
    }
}
