<?php
/**
 * enqueue_scripts
 * 
 * @author		Christian Lang
 * @version		1.0
 * @category	helper
 */

if ( ! function_exists('dt_load_theme_scripts') ) {
	/**
	 * load frontend scripts
	 */
	add_action('wp_enqueue_scripts', 'dt_load_theme_scripts');
	function dt_load_theme_scripts() {
		/* CSS */
		if ('1' != get_field('scripte_fa', 'option')) {
			wp_enqueue_style('font-awesome', 'https://netdna.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css');
		}

		wp_enqueue_style('open-sans', 'https://fonts.googleapis.com/css?family=Open+Sans:400,600');
		wp_enqueue_style('font-hind', 'https://fonts.googleapis.com/css?family=Hind:600');
		wp_enqueue_style('theme', get_template_directory_uri() . '/style.css');

		/* Custom Script */
		if ('1' != get_field('scripte_bootstrap_js', 'option')) {
			wp_enqueue_script('bootstrap', get_template_directory_uri() . '/_/js/bootstrap.min.js', array('jquery'), '3.4.1', true);
			wp_enqueue_script('scripts', get_template_directory_uri() . '/_/js/scripts.js', array('jquery', 'bootstrap'), DT_VERSION, true);
		} else {
			wp_enqueue_script('scripts', get_template_directory_uri() . '/_/js/scripts.js', array('jquery'), DT_VERSION, true);
		}

		/* Comment Script */
		if (is_single() && !is_home() && comments_open()) {
			wp_enqueue_script('comment-reply');
		}

		/* Lightbox */
		if ('1' != get_field('scripte_lightbox', 'option')) {
			wp_enqueue_style('lightbox', get_template_directory_uri() . '/_/css/lightbox.css');
			wp_enqueue_script('lightbox', get_template_directory_uri() . '/_/js/lightbox.js', array('jquery', 'bootstrap'), '1.3.5', true);

			wp_localize_script('lightbox', 'lightbox_vars', array(
					'lightbox_tPrev' => __('Vorheriges Bild (Linke Pfeiltaste)', 'datingtheme'),
					'lightbox_tNext' => __('Nächstes Bild (Rechte Pfeiltase)', 'datingtheme'),
					'lightbox_tCounter' => __('%curr% von %total%', 'datingtheme'),
				)
			);
		}

		/* Anti Bounce */
		if('1' == get_field('lustagenten_anti_bounce', 'option')) {
			$in_footer = (get_field('lustagenten_anti_bounce_pos', 'option') == 'header' ? false : true);
			$w = get_field('lustagenten_wm_id', 'option');
			$ws = get_field('lustagenten_wm_kpid',  'option');

			wp_enqueue_script('dt-ab', 'https://www.wazazu.com/LA/Dyn/Anti?w=' . $w . '&ws=' . $ws . '&ct=com', array('jquery'), '1.0', $in_footer);
		}

		/* Typeahead */
		if('1' != get_field('scripte_typeahead', 'option')) {
			wp_enqueue_script('typeahead', get_template_directory_uri() . '/_/js/jquery.typeahead.js', array('jquery', 'bootstrap'), '1.3.4', true);
		}
	}
}

if ( ! function_exists('dt_load_backend_styles') ) {
	/**
	 * load backend styles
	 */
	add_action('admin_enqueue_scripts', 'dt_load_backend_styles');
	function dt_load_backend_styles() {
		wp_enqueue_style('xcore-backend', get_template_directory_uri() . '/_/css/backend.css');

	}
}

if ( ! function_exists('dt_backend_editor_styles') ) {
	/**
	 * load backend editor styles
	 */
	add_action('admin_init', 'dt_backend_editor_styles');
	function dt_backend_editor_styles() {
		add_editor_style(get_template_directory_uri() . '/_/css/editor.css');
	}
}

if ( ! function_exists('dt_wp_disable_srcset') ) {
    /**
     * function dt_wp_disable_srcset
     */
    add_action('wp_calculate_image_srcset', 'dt_wp_disable_srcset');
    function dt_wp_disable_srcset($sources) {
        $resp_images = get_field('scripte_wp_responsive_images', 'option');

        if($resp_images == '1') {
            return array();
        }

        return $sources;
    }
}




