<?php
/*
 * Class Slugless_Rewrites
 *
 * @author		Christian Lang
 * @version		1.0
 * @category	locations
 */

if ( !class_exists( 'Slugless_Rewrites' ) ) :

    class Slugless_Rewrites {

        public $rules;

        public $post_type;

        public $query_var;

        public $hierarchical;

        public $has_archive;

        public $archive_feeds;

        public function __construct( $post_type, $args = array() ) {
            $args = wp_parse_args( $args, array(
                'hierarchical'  => false,
                'query_var'     => false,
                'has_archive'   => false,
                'archive_feeds' => true
            ) );

            $this->post_type = $post_type;

            $this->hierarchical = $args['hierarchical'];

            if ( $args['query_var'] )
                $this->query_var = $args['query_var'];
            else
                $this->query_var = $this->post_type;

            $this->has_archive = $args['has_archive'];

            $this->archive_feeds = $args['archive_feeds'];

            add_action( 'init',                             array( $this, 'add_rewrites' ),            20 );
            add_filter( 'request',                          array( $this, 'check_rewrite_conflicts' )     );
            add_filter( "{$this->post_type}_rewrite_rules", array( $this, 'strip_rules' )                 );
            add_filter( 'rewrite_rules_array',              array( $this, 'inject_rules' )                );
        }

        public function add_rewrites() {
            if ( $this->hierarchical )
                add_rewrite_tag( "%{$this->post_type}%", '(.+?)', "{$this->query_var}=" );
            else
                add_rewrite_tag( "%{$this->post_type}%", '([^/]+)', "{$this->query_var}=" );

            if ( ! empty( $this->has_archive ) )
                $this->add_archive_rules();

            add_permastruct( $this->post_type, "%{$this->post_type}%", array( 'ep_mask' => EP_PERMALINK ) );
        }

        public function add_archive_rules() {
            global $wp_rewrite;

            $archive_slug = $this->has_archive === true ? $this->post_type : $this->has_archive;

            add_rewrite_rule( "{$archive_slug}/?$", "index.php?post_type={$this->post_type}", 'top' );
            if ( $this->archive_feeds && $wp_rewrite->feeds ) {
                $feeds = '(' . trim( implode( '|', $wp_rewrite->feeds ) ) . ')';
                add_rewrite_rule( "{$archive_slug}/feed/$feeds/?$", "index.php?post_type={$this->post_type}" . '&feed=$matches[1]', 'top' );
                add_rewrite_rule( "{$archive_slug}/$feeds/?$", "index.php?post_type={$this->post_type}" . '&feed=$matches[1]', 'top' );
            }
            add_rewrite_rule( "{$archive_slug}/{$wp_rewrite->pagination_base}/([0-9]{1,})/?$", "index.php?post_type={$this->post_type}" . '&paged=$matches[1]', 'top' );
        }

        public function check_rewrite_conflicts( $qv ) {
            if ( isset( $qv[ $this->query_var ] ) ) {
                if ( get_page_by_path( $qv[ $this->query_var ] ) ) {
                    $qv['pagename'] = $qv[ $this->query_var ];
                    unset( $qv[ $this->query_var ], $qv['post_type'], $qv['name'] );
                }
            }
            return $qv;
        }

        public function strip_rules( $rules ) {
            $this->rules = $rules;
            # We no longer need the attachment rules, so strip them out
            foreach ( $this->rules as $regex => $value ) {
                if ( strpos( $value, 'attachment' ) )
                    unset( $this->rules[ $regex ] );
            }
            return array();
        }

        public function inject_rules( $rules ) {
            # This is the first 'page' rule
            $offset = array_search( '(.?.+?)/trackback/?$', array_keys( $rules ) );
            $page_rules = array_slice( $rules, $offset, null, true );
            $other_rules = array_slice( $rules, 0, $offset, true );
            return array_merge( $other_rules, $this->rules, $page_rules );
        }
    }

endif;