<?php
function dt_locations_geodata_update($data) {
    global $wpdb;

    $table_name = $wpdb->prefix . 'locations_geodata';

    // check date validity
    if( !is_float($data['lat']) || !is_float($data['lng']) || !is_int($data['post_id']) )
        return 0;

    $wpdb->query(
        $wpdb->prepare(
            "INSERT INTO $table_name (pid, lat, lng) VALUES(%d, %f, %f) ON DUPLICATE KEY UPDATE lat = %f, lng = %f",
            $data['post_id'], $data['lat'], $data['lng'], $data['lat'], $data['lng']
        )
    );
}

add_action('save_post', 'dt_locations_geodata_on_update', 10, 3);
function dt_locations_geodata_on_update($post_id, $post, $update) {
    $post_type = get_post_type($post_id);
    if ( "location" != $post_type ) return;

    if(!$_POST['acf']['field_572ca51f2a665'] || !$_POST['acf']['field_572ca5292a666'])
        return false;

    $data = array(
        'post_id' => $post_id,
        'lat' => floatval($_POST['acf']['field_572ca51f2a665']),
        'lng' => floatval($_POST['acf']['field_572ca5292a666'])
    );

    dt_locations_geodata_update($data);
}

function dt_locations_geodata_fill_table($offset = 0, $limit = 100) {
    global $wpdb;

    $locations = $wpdb->get_results(
        $wpdb->prepare(
            "
                SELECT DISTINCT p.ID, a.meta_value as lat, b.meta_value as lng FROM {$wpdb->posts} p
                LEFT JOIN {$wpdb->postmeta} a ON p.ID = a.post_id
                LEFT JOIN {$wpdb->postmeta} b ON p.ID = b.post_id
                WHERE a.meta_key = 'lat' AND a.meta_value != ''
				AND b.meta_key = 'lng' AND b.meta_value != ''
				AND p.post_type = '%s' AND p.post_status = 'publish'
                LIMIT $offset, $limit
            ", 'location'
        )
    );

    if(!$locations) {
        return false;
    }

    foreach($locations as $location) {
        $data = array(
            'post_id' => intval($location->ID),
            'lat' => floatval($location->lat),
            'lng' => floatval($location->lng)
        );

        dt_locations_geodata_update($data);
    }
}