<?php
class GeodataDashboard {
    private $options;

    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    public function add_plugin_page()
    {
        add_submenu_page(
            'edit.php?post_type=location',
            'Geodata',
            'Geodata',
            'edit_posts',
            'dt-location-geodata',
            array( $this, 'create_admin_page' )
        );
    }

    public function create_admin_page()
    {
        // check required table
        dt_locations_geodata_database();

        $this->options = get_option( 'dt_location_geodata' );
        $locations_count = $this->count_locations();
        $geodata_count = $this->count_geodata();
        ?>
        <div class="wrap">
            <h2><?php _e('Location Geodata', 'datingtheme'); ?></h2>
            <p><?php _e('Um Funktionen zu nutzen, welche Geodaten benötigen, brauchst du einen Index mit Geodaten. Das ist eine spezielle Datenbank welche die Koordinaten zu jeder angelegten Stadt enthält. <br><strong>Hinweis:</strong> Wundere dich nicht, wenn der Wert von verfügbaren Locations und Einträge im Index abweicht. Es werden Locations ohne Geodaten ignoriert.', 'datingtheme'); ?></p>
            <p><?php printf(__('Verfügbare Locations: %s', 'datingtheme'), $locations_count); ?></p>
            <p><?php printf(__('Aktuell im Index: %s', 'datingtheme'), $geodata_count); ?></p>
            <p><a href="#" class="button button-primary build-index"><?php _e('Index aufbauen', 'datingtheme'); ?></a></p>

            <div id="ajax-status">
                <p class="hint"><?php _e('<strong>Hinweis:</strong> Bitte die Seite während der Indexierung NICHT schließen!', 'datingtheme'); ?></p>

                <div class="progress">
                    <div class="progress-bar" style="width:0%;">0%</div>
                </div>
            </div>

            <script type="text/javascript">
                jQuery('.build-index').on('click', function() {
                    var iterations = 0;
                    var limit = <?php echo apply_filters('dt_location_geodata_build_index_limit', 100); ?>;
                    var geodata_count = <?php echo $geodata_count; ?>;
                    var locations_count = <?php echo $locations_count; ?>;

                    if(locations_count > 0) {
                        jQuery('#ajax-status').fadeIn();

                        iterations = Math.ceil(locations_count/limit);
                        for(i=1; i<=iterations; i++) {
                            build_index(i, iterations);
                        }
                    }
                });

                /*
                 * Function
                 * jQuery Queue
                 */
                (function($) {
                    var ajaxQueue = $({});
                    $.ajaxQueue = function(ajaxOpts) {
                        var oldComplete = ajaxOpts.complete;
                        ajaxQueue.queue(function(next) {
                            ajaxOpts.complete = function() {
                                if (oldComplete) oldComplete.apply(this, arguments);
                                next();
                            };
                            $.ajax(ajaxOpts);
                        });
                    };
                })(jQuery);

                function build_index(iteration, max) {
                    jQuery.ajaxQueue({
                        url: ajaxurl,
                        type: 'POST',
                        data: {action: 'dt_locations_geodata_build_index', offset: iteration * 100},
                        success: function(data){
                            var proc = Math.round(iteration / max * 100);
                            jQuery('.progress .progress-bar').css('width', proc + '%');
                            jQuery('.progress .progress-bar').html(proc + '%');

                            if(proc == 100) {
                                jQuery('.progress .progress-bar').css('width', proc + '%').css('background', '#3c763d');
                                jQuery('.progress .progress-bar').html('Indexierung abgeschlossen');
                            }
                        }
                    });
                }
            </script>

            <style>
                #ajax-status { display: none;  margin-top: 15px; }
                #ajax-status .hint { color: #c01313; }
                #ajax-status .progress { display: block; background: rgba(0,0,0,0.3); padding: 5px; max-width: 300px; margin: 15px 0; text-align: center; font-size: 12px; }
                #ajax-status .progress .progress-bar { background: #c01313; color:#fff;}
            </style>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {
        register_setting(
            'dt_location_geodata_group',
            'dt_location_geodata',
            array( $this, 'sanitize' )
        );

        add_settings_section(
            'dt_location_geodata_id',
            '',
            '',
            'dt-location-geodata'
        );
    }

    public function sanitize( $input )
    {
        return $input;
    }

    public function count_locations() {
        $locations = wp_count_posts('location');

        return $locations->publish;
    }

    public function count_geodata() {
        global $wpdb;

        $results = $wpdb->get_results("SELECT COUNT(id) AS count FROM {$wpdb->prefix}locations_geodata");

        if($results) {
            return $results[0]->count;
        }

        return '0';
    }
}

if( is_admin() ) {
    $profile_import = new GeodataDashboard();
}