<?php
if ( ! function_exists('dt_locations_geodata_database') ) {
    /**
     * dt_locations_geodata_database function.
     *
     */
    add_action('after_switch_theme', 'dt_locations_geodata_database');
    function dt_locations_geodata_database() {
        global $wpdb;

        $table_name = $wpdb->prefix . 'locations_geodata';

        /**
         * Installiere die Tabelle für die Geodaten
         */
        if ($wpdb->get_var("show tables like '" . $table_name . "'") != $table_name) {
            $sql = "CREATE TABLE " . $table_name . " (
                id int(11) NOT NULL AUTO_INCREMENT,
                pid int(11) NOT NULL,
                lat float NOT NULL,
                lng float NOT NULL ,
                PRIMARY KEY (id),
                UNIQUE KEY pid (pid)
            );";

            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
            dbDelta($sql);
        }
    }
}

if ( ! function_exists('dt_locations_geodata_database_install') ) {
    /**
     * dt_locations_geodata_database_install function.
     *
     */
    add_action('wp_ajax_dt_locations_geodata_database_install', 'dt_locations_geodata_database_install');
    function dt_locations_geodata_database_install() {
        dt_locations_geodata_database();

        $response = array();

        $response['status'] = 'ok';

        echo json_encode($response);

        exit();
    }
}

if ( ! function_exists('dt_locations_geodata_database_check') ) {
    /**
     * dt_locations_geodata_database_check function.
     *
     */
    add_action('admin_notices', 'dt_locations_geodata_database_check');
    function dt_locations_geodata_database_check() {
        global $wpdb;

        $table_name = $wpdb->prefix . 'locations_geodata';

        if ($wpdb->get_var("show tables like '" . $table_name . "'") != $table_name) {
            ?>
            <div class="error">
                <p>
                    <?php _e('Eine oder mehrere Datenbank-Tabellen für die Location <strong>Geodaten</strong> fehlen.
                    Bitte aktualisiere deine Datenbank. <a class="button" id="dt_locations_geodata_database_install">Datenbank aktualisieren</a>', 'datingtheme'); ?>
                </p>
            </div>

            <script type="text/javascript">
                jQuery('#dt_locations_geodata_database_install').bind('click', function (e) {
                    var target = jQuery(this).closest('.error');
                    jQuery(this).append(' <span class="spinner" style="visibility:initial"></span>');

                    jQuery.get(ajaxurl + '?&action=dt_locations_geodata_database_install', {}).done(function (data) {
                        var response = JSON.parse(data);

                        if (response.status == 'ok') {
                            jQuery(target).find('.spinner').remove();
                            jQuery(target).fadeOut();
                        }
                    });

                    e.preventDefault();
                });
            </script>
            <?php
        }
    }
}

if ( ! function_exists('dt_locations_geodata_update') ) {
    /**
     * dt_locations_geodata_update function.
     *
     */
    function dt_locations_geodata_update($data) {
        global $wpdb;

        $table_name = $wpdb->prefix . 'locations_geodata';

        // check date validity
        if (!is_float($data['lat']) || !is_float($data['lng']) || !is_int($data['post_id']))
            return 0;

        $wpdb->query(
            $wpdb->prepare(
                "INSERT INTO $table_name (pid, lat, lng) VALUES(%d, %f, %f) ON DUPLICATE KEY UPDATE lat = %f, lng = %f",
                $data['post_id'], $data['lat'], $data['lng'], $data['lat'], $data['lng']
            )
        );
    }
}

if ( ! function_exists('dt_locations_geodata_on_update') ) {
    /**
     * dt_locations_geodata_on_update function.
     *
     */
    add_action('save_post', 'dt_locations_geodata_on_update', 10, 3);
    function dt_locations_geodata_on_update($post_id, $post, $update) {
        $post_type = get_post_type($post_id);
        if ("location" != $post_type) return;

        if (!$_POST['acf']['field_572ca51f2a665'] || !$_POST['acf']['field_572ca5292a666'])
            return false;

        $data = array(
            'post_id' => $post_id,
            'lat' => floatval($_POST['acf']['field_572ca51f2a665']),
            'lng' => floatval($_POST['acf']['field_572ca5292a666'])
        );

        dt_locations_geodata_update($data);
    }
}

if ( ! function_exists('dt_locations_geodata_build_index') ) {
    /**
     * dt_locations_geodata_build_index function.
     *
     */
    add_action('wp_ajax_dt_locations_geodata_build_index', 'dt_locations_geodata_build_index');
    function dt_locations_geodata_build_index() {
        $offset = (isset($_POST['offset']) ? $_POST['offset'] : 0);
        $limit = (isset($_POST['limit']) ? $_POST['limit'] : apply_filters('dt_location_geodata_build_index_limit', 100));

        dt_locations_geodata_fill_table($offset, $limit);
        exit;
    }
}

if ( ! function_exists('dt_locations_geodata_fill_table') ) {
    /**
     * dt_locations_geodata_fill_table function.
     *
     */
    function dt_locations_geodata_fill_table($offset = 0, $limit = 100) {
        global $wpdb;

        $locations = $wpdb->get_results(
            $wpdb->prepare(
                "
                    SELECT DISTINCT p.ID, a.meta_value as lat, b.meta_value as lng FROM {$wpdb->posts} p
                    LEFT JOIN {$wpdb->postmeta} a ON p.ID = a.post_id
                    LEFT JOIN {$wpdb->postmeta} b ON p.ID = b.post_id
                    WHERE a.meta_key = 'lat' AND a.meta_value != ''
                    AND b.meta_key = 'lng' AND b.meta_value != ''
                    AND p.post_type = '%s' AND p.post_status = 'publish'
                    LIMIT $offset, $limit
                ", 'location'
            )
        );

        if (!$locations) {
            return false;
        }

        foreach ($locations as $location) {
            $data = array(
                'post_id' => intval($location->ID),
                'lat' => floatval($location->lat),
                'lng' => floatval($location->lng)
            );

            dt_locations_geodata_update($data);
        }
    }
}

if ( ! function_exists('dt_locations_geodata_nearby') ) {
    /**
     * dt_locations_geodata_nearby function.
     *
     */
    function dt_locations_geodata_nearby($post_id, $distance = 10, $limit = 10) {
        $lat = get_post_meta($post_id, 'lat', true);
        $lng = get_post_meta($post_id, 'lng', true);

        if (!$lat || !$lng)
            return false;

        global $wpdb;

        $results = $wpdb->get_results("SELECT *, (3959 * acos(cos(radians('$lat')) * cos(radians(lat)) * cos(radians(lng) - radians($lng)) + sin(radians('$lat')) * sin(radians(lat)))) AS distance FROM {$wpdb->prefix}locations_geodata WHERE pid != '$post_id' HAVING distance < $distance ORDER BY distance LIMIT 0 , $limit ");

        if ($results) {
            return $results;
        }

        return false;
    }
}