<?php
/*
 * Helper
 * 
 * @author		Christian Lang
 * @version		1.0
 * @category	locations
 */

add_filter('dt_profile_city', 'dt_overwrite_profile_city', 11, 3);
function dt_overwrite_profile_city($output, $profile, $archive) {;
    if($archive) {
        return get_the_title($archive);
    }

    return $output;
}

if ( ! function_exists('dt_city_title_filter') ) {
    /**
     * dt_city_title_filter function.
     *
     */
    function dt_city_title_filter($where, $wp_query) {
        global $wpdb;
        if ($search_term = $wp_query->get('search_prod_title')) {
            $where .= ' AND ' . $wpdb->posts . '.post_title LIKE \'' . esc_sql($search_term) . '%\'';
        }
        return $where;
    }
}

if ( ! function_exists('dt_add_location_import_notice') ) {
    /**
     * dt_add_location_import_notice function.
     *
     */
    add_action('admin_notices', 'dt_add_location_import_notice');
    function dt_add_location_import_notice() {
        if ((isset($_GET['post_type']) && $_GET['post_type'] == 'location')) {
            ?>
            <div class="notice notice-info is-dismissible">
                <h3><span
                        class="dashicons dashicons-megaphone"></span> <?php _e('Import von Einträgen', 'datingtheme'); ?>
                </h3>
                <p><?php _e('Wir bieten dir die Möglichkeit eine Liste von allen Bundesländer inkl. der jeweiligen Städte zu importieren. Dieser Datenbestand enthält ingesamt <strong>12.247 Einträge</strong>. Eine <strong>Anleitung</strong> zu diesem Import findest du <a href="https://www.datingtheme.io/dokumentation/" target="blank">hier</a>.', 'datinghtme'); ?></p>
            </div>
            <?php
        }
    }
}

if ( ! function_exists('dt_add_location_import_notice') ) {
    /**
     * dt_add_location_import_notice function.
     *
     */
    add_action('wp_ajax_get_city_autocomplete', 'dt_get_city_autocomplete');
    add_action('wp_ajax_nopriv_get_city_autocomplete', 'dt_get_city_autocomplete');
    function dt_get_city_autocomplete() {
        $q = $_GET['q'];

        if (!$q)
            return;

        global $wpdb;

        $results = $wpdb->get_results("SELECT post_title FROM $wpdb->posts WHERE post_title LIKE '" . $q . "%' AND post_type = 'location' AND post_status = 'publish' LIMIT 0,20");

        if ($results) {
            $output = array();
            foreach ($results as $item) {
                $output[] = $item->post_title;
            }
            echo json_encode($output);
        }

        exit;
    }
}

if ( ! function_exists('dt_location_remove_comments_rss') ) {
    /**
     * dt_location_remove_comments_rss function.
     *
     */
    add_filter('post_comments_feed_link', 'dt_location_remove_comments_rss');
    function dt_location_remove_comments_rss($for_comments) {
        if (get_post_type() == 'location') {
            return;
        }

        return $for_comments;
    }
}

if ( ! function_exists('dt_get_country_states_title') ) {
    /**
     * dt_get_country_states_title function.
     *
     */
    function dt_get_country_states_title($post_id) {
        $title = get_the_title($post_id);

        switch ($title) {
            case 'Schweiz':
                return __('Alle Kantone', 'datingtheme');
                break;

            default:
                return __('Alle Bundesländer', 'datingtheme');
                break;
        }

        return false;
    }
}

if ( ! function_exists('dt_get_country_states_ids') ) {
    /**
     * dt_get_country_states_ids function.
     *
     */
    function dt_get_country_states_ids($post_id) {
        $args = array(
            'post_type' => 'location',
            'meta_query' => array(
                array(
                    'key' => 'typ',
                    'value' => 'state'
                )
            ),
            'fields' => 'ids',
            'posts_per_page' => -1,
            'post_parent' => $post_id
        );

        $states = get_posts($args);

        if($states) {
            return $states;
        }

        return array();
    }
}

function dt_get_profile_taxonomy_args($args = array()) {
    $posts_per_page = (get_field('profile_taxonomy_numberposts', 'options') ? get_field('profile_taxonomy_numberposts', 'options') : 30);
    $orderby = (get_field('profile_taxonomy_orderby', 'options') ? get_field('profile_taxonomy_orderby', 'options') : 'rand');
    $order = (get_field('profile_taxonomy_order', 'options') ? get_field('profile_taxonomy_order', 'options') : 'desc');

    if($order_args = dt_get_profile_orderby_args($orderby, $order)) {
        $args = array_merge($args, $order_args);
    }

    $args['post_type'] = 'profile';
    $args['posts_per_page'] = $posts_per_page;

    /*
     * Profile details
     */
    $gender = (get_field('profile_taxonomy_gender', 'options') ? get_field('profile_taxonomy_gender', 'options') : '');
    $age_from = (get_field('profile_taxonomy_age_from', 'options') ? get_field('profile_taxonomy_age_from', 'options') : '');
    $age_to = (get_field('profile_taxonomy_age_to', 'options') ? get_field('profile_taxonomy_age_to', 'options') : '');
    $figure = (get_field('profile_taxonomy_figure', 'options') ? get_field('profile_taxonomy_figure', 'options') : '');
    $hair_color = (get_field('profile_taxonomy__hair_color', 'options') ? get_field('profile_taxonomy__hair_color', 'options') : '');
    $weight_from = (get_field('profile_taxonomy_weight_from', 'options') ? get_field('profile_taxonomy_weight_from', 'options') : '');
    $weight_to = (get_field('profile_taxonomy_weight_to', 'options') ? get_field('profile_taxonomy_weight_to', 'options') : '');
    $size_from = (get_field('profile_taxonomy_size_from', 'options') ? get_field('profile_taxonomy_size_from', 'options') : '');
    $size_to = (get_field('profile_taxonomy_size_to', 'options') ? get_field('profile_taxonomy_size_to', 'options') : '');

    /*
     * Geschlecht
     */
    if($gender) {
        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_gender',
                'value'     => $gender
            )
        );
    }

    /*
    * Alter
    */
    if($age_from || $age_to) {
        if ($age_from == '') {
            $age_from = '0';
        }

        if ($age_to == '') {
            $age_to = '999';
        }

        $args['meta_query'][] = array(
            array(
                'key' => 'profile_age',
                'value' => array($age_from, $age_to),
                'compare' => 'BETWEEN',
                'type' => 'NUMERIC'
            )
        );
    }

    /*
     * Figur
     */
    if($figure) {
        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_figure',
                'value'     => $figure
            )
        );
    }

    /*
     * Haarfarbe
     */
    if($hair_color) {
        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_hair_color',
                'value'     => $hair_color
            )
        );
    }

    /*
    * Gewicht
    */
    if($weight_from || $weight_to) {
        if($weight_from == '') {
            $weight_from = '0';
        }

        if($weight_to == '') {
            $weight_to = '999';
        }

        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_weight',
                'value'     => array($weight_from, $weight_to),
                'compare'   => 'BETWEEN',
                'type'      => 'NUMERIC'
            )
        );
    }

    /*
    * Größe
    */
    if($size_from || $size_to) {
        if($size_from == '') {
            $size_from = '0';
        }

        if($size_to == '') {
            $size_to = '999';
        }

        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_size',
                'value'     => array($size_from, $size_to),
                'compare'   => 'BETWEEN',
                'type'      => 'NUMERIC'
            )
        );
    }

    return $args;
}
