<?php
/**
 * Hilfsfunktionen
 *
 * @author		Christian Lang
 * @version		1.0
 * @category	popup
 */

if ( ! function_exists('dt_load_popup_scripts') ) {
    /**
     * dt_load_popup_scripts function.
     *
     */
    add_action('wp_enqueue_scripts', 'dt_load_popup_scripts');
    function dt_load_popup_scripts() {
        wp_enqueue_script('ouibounce', get_template_directory_uri() . '/_/js/ouibounce.min.js', array('jquery', 'bootstrap'), '1.2', true);
    }
}

if ( ! function_exists('dt_load_popup_code') ) {
    /**
     * dt_load_popup_code function.
     *
     */
    add_action('wp_footer', 'dt_load_popup_code', 99);
    function dt_load_popup_code() {
        if (is_user_logged_in()) {
            return;
        }

        $desktop = get_field('popup_desktop', 'option');
        $mobile = get_field('popup_mobile', 'option');

        if (wp_is_mobile()) {
            if ($mobile != '1')
                return;

            get_template_part('parts/popup/modal', 'mobile');
        } else {
            if ($desktop != '1')
                return;

            get_template_part('parts/popup/modal', 'desktop');
        }

        $show_after_time = get_field('popup_show_after_time', 'option');
        $show_after_scroll = get_field('popup_show_after_scroll', 'option');
        $cookie = get_field('popup_cookie', 'option');
        $cookie_expire = (get_field('popup_cookie_expire', 'option') ? get_field('popup_cookie_expire', 'option') : '1');

        echo '<script type="text/javascript">';
        echo '
                var _ouibounce = ouibounce(false, {
                    timer: 0,
                    ' . ($cookie ? 'cookieExpire: "' . $cookie_expire . '",' : '') . '
                    callback: function() {
                        jQuery("#popupDesktop").modal("show");
                    }
                });
    
                jQuery("#popupDesktop").on("shown.bs.modal", function () {
                    jQuery("body").removeClass("modal-open");
                })
                ';

        if ($show_after_time != '0') {
            echo '
                    jQuery(document).ready(function() {
                        jQuery(function(){
                            setTimeout(function(){
                                _ouibounce.fire();
                            }, ' . $show_after_time . ');
                        });
                    });
                    ';
        }

        if ($show_after_scroll != '0') {
            echo '
                jQuery(document).scroll(function(e){
                    var scrollAmount = jQuery(window).scrollTop();
                    var documentHeight = jQuery(document).height();
                    var scrollPercent = (scrollAmount / documentHeight) * 100;
                    var showAfter = "' . $show_after_scroll . '";
    
                    if(scrollPercent > showAfter) {
                        _ouibounce.fire();
                    }
                });';
        }
        echo '</script>';
    }
}