<?php
if(!class_exists('Profile')) {
    class Profile {
        var $post_id;
        var $archive;

        function __construct($post_id, $archive = '') {
            $this->post_id = $post_id;
            $this->archive = $archive;
        }

        function getImage($layout = 'grid') {
            $classes = array('contact-image');

            if($layout == 'media') {
                $classes[] = 'media-object';
                $size = 'full';
            } else {
                $classes[] = 'img-responsive';
                $size = 'profile_grid';
            }

            if(has_post_thumbnail($this->post_id)) {
                return get_the_post_thumbnail($this->post_id, $size, array('class' => implode(' ', $classes), 'alt' => $this->getName()));
            } else {
                $file = 'placeholder-320x240.jpg';

                if($this->getGenderRaw() == 'female') {
                    $file = 'placeholder-f-320x240.jpg';
                } else if($this->getGenderRaw() == 'male') {
                    $file = 'placeholder-m-320x240.jpg';
                } else if($this->getGenderRaw() == 'FF' || $this->getGenderRaw() == 'FM' || $this->getGenderRaw() == 'NM') {
                    $file = 'placeholder-c-320x240.jpg';
                }

                return '<img src="' . get_template_directory_uri() . '/_/img/' . $file . '" class="' . implode(' ', $classes) . '" alt="' . $this->getName() . '" />';
            }
        }

        function getDescription() {
            return apply_filters('the_content', get_post_field('post_content', $this->post_id));
        }

        function getName() {
            return apply_filters('dt_profile_name', get_the_title($this->post_id), $this->post_id);
        }

        function getCity() {
            global $wp_query, $wpdb;

            if(isset($_GET['city'])) {
                return htmlspecialchars($_GET['city']);
            }

            if(get_post_type($wp_query->queried_object_id) == 'location') {
                if(get_field('typ', $wp_query->queried_object_id) == 'state') {
                    $random = $wpdb->get_row('SELECT ID, post_title FROM ' . $wpdb->posts . ' WHERE post_type = "location" AND post_status = "publish" AND post_parent = "' . $wp_query->queried_object_id. '" ORDER BY RAND() LIMIT 1');
                    if($random) {
                        return $random->post_title;
                    }
                }

                return get_the_title($wp_query->queried_object_id);
            }

            if(get_field('profile_city', $this->post_id)) {
                return apply_filters('dt_profile_city', get_field('profile_city', $this->post_id), $this->post_id, $this->archive);
            }

            $random = $wpdb->get_row('SELECT ID, post_title FROM ' . $wpdb->posts . ' WHERE post_type = "location" AND post_status = "publish" ORDER BY RAND() LIMIT 1');

            if($random) {
                return $random->post_title;
            }
        }

        function getCityLinked() {
            global $wp_query, $wpdb;

            if(isset($_GET['city'])) {
                return htmlspecialchars($_GET['city']);
            }

            if(get_post_type($wp_query->queried_object_id) == 'location') {
                if(get_field('typ', $wp_query->queried_object_id) == 'state') {
                    $random = $wpdb->get_row('SELECT ID, post_title FROM ' . $wpdb->posts . ' WHERE post_type = "location" AND post_status = "publish" AND post_parent = "' . $wp_query->queried_object_id. '" ORDER BY RAND() LIMIT 1');
                    if($random) {
                        return '<a href="' . get_permalink($random->ID) . '">' . $random->post_title . '</a>';
                    }
                }
                return '<a href="' . get_permalink($wp_query->queried_object_id) . '">' . get_the_title($wp_query->queried_object_id) . '</a>';
            }

            if(get_field('profile_city', $this->post_id)) {
                // try to get location by title
                $link = '';
                $location_by_title = get_page_by_title(get_field('profile_city', $this->post_id), 'OBJECT', 'location');

                if($location_by_title) {
                    $link = get_permalink($location_by_title->ID);

                    if($link) {
                        return apply_filters('dt_profile_city', '<a href="' . $link . '">' . get_field('profile_city', $this->post_id) . '</a>', $this->post_id, $this->archive);
                    }
                }
                
                return $this->getCity();
            }

            $random = $wpdb->get_row('SELECT ID, post_title FROM ' . $wpdb->posts . ' WHERE post_type = "location" AND post_status = "publish" ORDER BY RAND() LIMIT 1');

            if($random) {
                return '<a href="' . get_permalink($random->ID) . '">' . $random->post_title . '</a>';
            }
        }

        function getAge() {
            return apply_filters('dt_profile_age', get_field('profile_age', $this->post_id), $this->post_id);
        }

        function getGenderRaw() {
            return apply_filters('dt_profile_gender_raw', get_field('profile_gender', $this->post_id), $this->post_id);
        }

        function getGender() {
            $gender = $this->getGenderRaw();

            switch($gender) {
                case 'female':
                    $output = __('Weiblich', 'datingtheme');
                    break;

                case 'male':
                    $output = __('Männlich', 'datingtheme');
                    break;

                case 'T':
                    $output = __('Transvestit', 'datingtheme');

                case 'S':
                    $output = __('Shemale/Transsexuell', 'datingtheme');

                case 'FF':
                    $output = __('Paar (Frau/Frau)', 'datingtheme');

                case 'FM':
                    $output = __('Paar (Frau/Mann)', 'datingtheme');

                case 'MM':
                    $output = __('Paar (Mann/Mann)', 'datingtheme');

                default:
                    $output = '';
            }

            return apply_filters('dt_profile_gender', $output, $this->post_id);
        }

        function getFigure() {
            return apply_filters('dt_profile_figure', get_field('profile_figure', $this->post_id), $this->post_id);
        }

        function getHairColor() {
            return apply_filters('dt_profile_hair_color', get_field('profile_hair_color', $this->post_id), $this->post_id);
        }

        function getSizeRaw() {
            return apply_filters('dt_profile_size_raw', get_field('profile_size', $this->post_id), $this->post_id);
        }

        function getSize() {
            return apply_filters('dt_profile_size', get_field('profile_size', $this->post_id) . __(' cm', 'datingtheme'), $this->post_id);
        }

        function getWeightRaw() {
            return apply_filters('dt_profile_weight_raw', get_field('profile_weight', $this->post_id), $this->post_id);
        }

        function getWeight() {
            return apply_filters('dt_profile_weight', get_field('profile_weight', $this->post_id) . __(' kg', 'datingtheme'), $this->post_id);
        }

        function getLink() {
            $profile_ad = get_field('profile_ad', $this->post_id);
            if($profile_ad == '1') {
                $profile_ad_url = get_field('profile_ad_url', $this->post_id);

                if($profile_ad_url) {
                    return ' href="' . $profile_ad_url . '" target="_blank" rel="nofollow" ';
                }
            }

            return ' href="#" data-toggle="modal" data-target="#ContactModal" ';
        }
    }
}
