<?php
/**
 * Helper
 * 
 * @author		Christian Lang
 * @version		1.0
 * @category	profiles
 */

add_image_size('profile_grid', 320, 240, true);

if ( ! function_exists('dt_add_profile_import_notice') ) {
    /**
     * dt_add_profile_import_notice function.
     *
     */
    add_action('admin_notices', 'dt_add_profile_import_notice');
    function dt_add_profile_import_notice() {
        if ((isset($_GET['post_type']) && $_GET['post_type'] == 'profile') && !isset($_GET['page'])) {
            ?>
            <div class="notice notice-info is-dismissible">
                <h3><span class="dashicons dashicons-megaphone"></span> <?php _e('Import von Einträgen', 'datingtheme'); ?></h3>
                <p><?php _e('Wir bieten dir die Möglichkeit Profile von VX-CASH zu importieren. Das Dashboard hierzu findest du <a href="' . admin_url("/edit.php?post_type=profile&page=dt-profile-import") . '">hier</a>.', 'datinghtme'); ?></p>
            </div>
            <?php
        }
    }
}

if ( ! function_exists('dt_get_column_class') ) {
    /**
     * dt_get_column_class function.
     *
     */
    function dt_get_column_class($num = 6) {
        switch($num) {
            case 6:
                return 'col-sm-2';
                break;

            case 5:
                return 'col-sm-15';
                break;

            case 4:
                return 'col-sm-3';
                break;

            case 3:
                return 'col-sm-4';
                break;

            case 2:
                return 'col-sm-6';
                break;

            default:
                return 'col-sm-2';
                break;
        }

        return 'col-sm-2';
    }
}

if ( ! function_exists('dt_profile_get_city') ) {
    /**
     * dt_profile_get_city function.
     *
     */
    function dt_profile_get_city($post_id) {
        $city = apply_filters('dt_profile_city', get_field('profile_city', $post_id));

        if($city) {
            return $city;
        }

        return false;
    }
}

if ( ! function_exists('dt_profile_get_button_text') ) {
    /**
     * dt_profile_get_button_text function.
     *
     */
    function dt_profile_get_button_text() {
        $text = get_field('profile_misc_button_text', 'options');

        if(!$text) {
            $text = apply_filters('dt_profile_button_text', __('Nachricht senden <i class="fa fa-heart"></i>', 'datingtheme'));
        }

        return $text;
    }
}

if ( ! function_exists('dt_profile_get_status') ) {
    /**
     * dt_profile_get_status function.
     *
     */
    function dt_profile_get_status() {
        $status = get_field('profile_misc_status', 'options');

        if($status == '1') {
            $output = '<span class="label label-online">' .  __("online", "datingtheme") . '</span>';
            return $output;
        }

        return false;
    }
}

if ( ! function_exists('dt_profile_get_popup_headline') ) {
    /**
     * dt_profile_get_popup_headline function.
     *
     */
    function dt_profile_get_popup_headline() {
        $text = get_field('profile_popup_headline', 'options');

        if(!$text) {
            $text = apply_filters('dt_profile_popup_headline', __('Registriere Dich jetzt kostenlos für private Sexkontakte!', 'datingtheme'));
        }

        return $text;
    }
}

if ( ! function_exists('dt_profile_get_popup_seal') ) {
    /**
     * dt_profile_get_popup_seal function.
     *
     */
    function dt_profile_get_popup_seal($html = true) {
        $image = get_field('profile_popup_seal', 'options');
        $hide = get_field('profile_popup_seal_hide', 'options');

        if($hide == '1') {
            return false;
        }

        if(!$image) {
            $image = array(
                'url' => get_template_directory_uri() . '/_/img/siegel.png',
                'width' => '161',
                'height' => '161',
                'alt' => __('Nur echte Kontakte - 100% REAL!', 'datingtheme')
            );
        }

        if($html) {
            $output = '<img src="' . $image['url'] . '" width="' . $image['width'] . '" height="' . $image['height'] . '" class="alignright img-responsive img-seal" alt="' . $image['alt'] . '"/>';

            return $output;
        }

        return $image;
    }
}

if ( ! function_exists('dt_profile_get_popup_button_text') ) {
    /**
     * dt_profile_get_popup_button_text function.
     *
     */
    function dt_profile_get_popup_button_text() {
        $text = get_field('profile_popup_button_text', 'options');

        if(!$text) {
            $text = apply_filters('profile_popup_button_text', __('Jetzt kostenlos anmelden »', 'datingtheme'));
        }

        return $text;
    }
}


add_filter('manage_profile_posts_columns', 'dt_profiles_columns');
function dt_profiles_columns( $defaults ) {
    unset($defaults['author']);
    unset($defaults['date']);

    $defaults['title']  = __('Name', 'datingtheme');
    $defaults['gender']  = __('Geschlecht', 'datingtheme');
    $defaults['age']  = __('Alter', 'datingtheme');
    $defaults['figure']  = __('Figur', 'datingtheme');
    $defaults['hair_color']  = __('Haarfarbe', 'datingtheme');
    $defaults['size']  = __('Größe', 'datingtheme');
    $defaults['weight']  = __('Gewicht', 'datingtheme');
    return $defaults;
}

add_action( 'manage_profile_posts_custom_column', 'dt_profiles_columns_action', 10, 2 );
function dt_profiles_columns_action( $column_name, $post_id ) {
    $profile = new Profile($post_id);

    if ($column_name == 'gender') {
        echo $profile->getGender();
    }

    if ($column_name == 'age') {
        echo $profile->getAge();
    }

    if ($column_name == 'figure') {
        echo $profile->getFigure();
    }

    if ($column_name == 'hair_color') {
        echo $profile->getHairColor();
    }

    if ($column_name == 'size') {
        echo $profile->getSize();
    }

    if ($column_name == 'weight') {
        echo $profile->getWeight();
    }
}

function dt_get_profile_orderby_args($orderby = 'rand', $order = 'desc', $shortcode = false) {
    $args = array(
        'order' => $order
    );

    if($orderby == 'gender' || $orderby == 'age' || $orderby == 'weight' || $orderby == 'size') {
        $args['meta_key'] = 'profile_' . $orderby;
        $args['orderby'] = 'meta_value';
    } else {
        $args['orderby'] = $orderby;
    }

    if($shortcode) {
        $output = ' orderby="' . $args['orderby'] . '" order="' . $args['order'] . '" ';

        return $output;
    }

    return $args;
}

function dt_profile_check_import_status($unique_key, $unique_val) {
	global $wpdb;
	
	if ($unique = $wpdb->get_var("SELECT post_id FROM " . $wpdb->postmeta . " WHERE meta_key = '" . $unique_key . "' AND meta_value = '" . $unique_val . "' LIMIT 0,1")) {
		// update table
		$wpdb->update(
			DT_PROFILE_IMPORT_IDS,
			array( 'imported' => 1 ),
			array( 'userid' => $unique_val ),
			array( '%d' ),
			array( '%d' )
		);

		return true;
	}
	
	return false;
}

if ( ! function_exists('dt_attach_external_image') ) {
    /**
     * dt_attach_external_image function.
     *
     * @param  string $url
     * @param  int $post_id
     * @param  string $thumb
     * @param  string $filename
     * @param  array $postdata
     * @return boolean
     */
    function dt_attach_external_image($url = null, $post_id = null, $thumb = null, $filename = null, $post_data = array()) {
        if (!$url || !$post_id) return new WP_Error('missing', "Need a valid URL and post ID...");
        require_once(ABSPATH . "wp-admin" . '/includes/image.php');
        require_once(ABSPATH . "wp-admin" . '/includes/file.php');
        require_once(ABSPATH . "wp-admin" . '/includes/media.php');
        // Download file to temp location, returns full server path to temp file, ex; /home/user/public_html/mysite/wp-content/26192277_640.tmp
        $tmp = download_url($url);

        // If error storing temporarily, unlink
        if (is_wp_error($tmp)) {
            @unlink($file_array['tmp_name']);   // clean up
            $file_array['tmp_name'] = '';
            return $tmp; // output wp_error
        }

        preg_match('/[^\?]+\.(jpg|JPG|jpe|JPE|jpeg|JPEG|gif|GIF|png|PNG)/', $url, $matches);    // fix file filename for query strings
        $url_filename = basename($matches[0]);                                                  // extract filename from url for title
        $url_type = wp_check_filetype($url_filename);                                           // determine file type (ext and mime/type)

        // override filename if given, reconstruct server path
        if (!empty($filename)) {
            $filename = sanitize_file_name($filename);
            $tmppath = pathinfo($tmp);                                                        // extract path parts
            $new = $tmppath['dirname'] . "/" . $filename . "." . $tmppath['extension'];          // build new path
            rename($tmp, $new);                                                                 // renames temp file on server
            $tmp = $new;                                                                        // push new filename (in path) to be used in file array later
        }

        // assemble file data (should be built like $_FILES since wp_handle_sideload() will be using)
        $file_array['tmp_name'] = $tmp;                                                         // full server path to temp file

        if (!empty($filename)) {
            $file_array['name'] = $filename . "." . $url_type['ext'];                           // user given filename for title, add original URL extension
        } else {
            $file_array['name'] = $url_filename;                                                // just use original URL filename
        }

        // set additional wp_posts columns
        if (empty($post_data['post_title'])) {
            $post_data['post_title'] = basename($url_filename, "." . $url_type['ext']);         // just use the original filename (no extension)
        }

        // make sure gets tied to parent
        if (empty($post_data['post_parent'])) {
            $post_data['post_parent'] = $post_id;
        }

        // do the validation and storage stuff
        $att_id = media_handle_sideload($file_array, $post_id, null, $post_data);             // $post_data can override the items saved to wp_posts table, like post_mime_type, guid, post_parent, post_title, post_content, post_status

        // If error storing permanently, unlink
        if (is_wp_error($att_id)) {
            @unlink($file_array['tmp_name']);   // clean up
            return $att_id; // output wp_error
        }

        // set as post thumbnail if desired
        if ($thumb) {
            set_post_thumbnail($post_id, $att_id);
        }

        return $att_id;
    }
}