<?php
class CrawlProfiles {
    public $urls = array(
        'users' => 'https://www.visit-x.net/VXCASHREST/v1/dating/getIds',
        'user' => 'https://www.visit-x.net/VXCASHREST/v1/dating/getData/user_id',
    );
    public $options;
    public $wid;
    public $api_key;
    public $last_report_setting = 'dt_profile_import_last_report';
    public $last_crawl_setting = 'dt_profile_import_last_crawl';
    public $last_crawl_error_setting = 'dt_profile_import_last_crawl_error';
    public $last_import_setting = 'dt_profile_import_last_import';

    public function __construct() {
        $this->options = get_option( 'dt_profile_import' );
        $this->wid = get_field('lustagenten_wm_id', 'options');
        $this->api_key = get_field('lustagenten_api_key', 'options');

        add_filter( 'cron_schedules', 'dt_remove_profiles_interval' );
        function dt_remove_profiles_interval( $schedules ) {
            $schedules['15min'] = array(
                'interval' => 900,
                'display'  => esc_html__( '15min' ),
            );

            $schedules['30min'] = array(
                'interval' => 1800,
                'display'  => esc_html__( '30min' ),
            );

            $schedules['weekly'] = array(
                'interval' => 604800,
                'display'  => esc_html__( 'Once Weekly' ),
            );

            $schedules['9days'] = array(
                'interval' => 777600,
                'display'  => esc_html__( 'every 9 days' ),
            );

            return $schedules;
        }

        add_action( 'wp_ajax_dt_crawl_profiles', array( $this, 'getProfiles' ) );
        add_action( 'wp_ajax_nopriv_dt_crawl_profiles', array( $this, 'getProfiles' ) );
        add_action( 'dt_event_crawl_profiles', array( $this, 'getProfiles' ) );

        add_action( 'wp_ajax_dt_save_profiles', array( $this, 'saveProfiles' ) );
        add_action( 'wp_ajax_nopriv_dt_save_profiles', array( $this, 'saveProfiles' ) );
        add_action( 'dt_event_save_profiles', array( $this, 'saveProfiles' ) );

        add_action( 'wp_ajax_dt_remove_profiles', array( $this, 'removeProfiles' ) );
        add_action( 'wp_ajax_nopriv_dt_remove_profiles', array( $this, 'removeProfiles' ) );
        add_action( 'dt_event_remove_profiles', array( $this, 'removeProfiles' ) );

        if ( ! wp_next_scheduled( 'dt_event_crawl_profiles' ) ) {
            wp_schedule_event( time(), 'weekly', 'dt_event_crawl_profiles');
        }

        if ( ! wp_next_scheduled( 'dt_event_save_profiles' ) ) {
            wp_schedule_event( time(), dt_profile_get_import_interval(), 'dt_event_save_profiles');
        }

        if ( ! wp_next_scheduled( 'dt_event_remove_profiles' ) ) {
            wp_schedule_event( time(), '9days', 'dt_event_remove_profiles');
        }

        if(!isset($this->options['status']) || $this->options['status'] != '1') {
            wp_clear_scheduled_hook( 'dt_event_crawl_profiles' );
            wp_clear_scheduled_hook( 'dt_event_save_profiles' );
            wp_clear_scheduled_hook( 'dt_event_remove_profiles' );
        }
    }

    public function load_data($url, $param = array()) {
        // build URL
        $target = $url;

        // check if connection is temp. closed
        $connection_closed = get_option( $this->last_crawl_error_setting );
        if($connection_closed && is_numeric($connection_closed)) {
            $time_expired = strtotime("+2 minutes", $connection_closed);

            if(time() < $time_expired) {
                // wait
                update_option($this->last_report_setting, sprintf(__('Zugriff auf API für weitere %s Minuten gesperrt.', 'datingtheme'), date('i:s', (120 - (time() - $connection_closed)))));
                return 'wait';
            } else {
                // try a new run
                update_option($this->last_crawl_error_setting, '');
            }
        }

        if($this->wid && $this->api_key) {
            $target .= '?w=' . $this->wid . '&key=' . $this->api_key . '&ws=.wpd';
        } else {
            update_option($this->last_report_setting, __('Webmaster ID oder API Key nicht gesetzt.', 'datingtheme'));
            return false;
        }

        if($param) {
            if($param['user_id']) {
                $target = str_replace('user_id', $param['user_id'], $target);
            }
        }

        $html = file_get_contents($target);

        if($html === 'null' && ini_get( 'allow_url_fopen' )) {
            return 'gone_away';
        }
		
        if($http_response_header) {
            $status = $http_response_header[0];
            if(strpos($status, '503') !== false) {
                update_option($this->last_crawl_error_setting, time());
                update_option($this->last_report_setting, __('Zugriff auf API für 2 Minuten gesperrt.', 'datingtheme'));
                return 'wait';
            }
        }

        if($html) {
            $data = json_decode($html, true);
            if (is_array($data)) {
                return $data;
            } else {
                $data = json_decode($html);
                return $data;
            }
        }

        update_option($this->last_report_setting, __('Daten können nicht abgerufen werden, bitte den API Key überprüfen.', 'datingtheme'));

        return false;
    }

    public function getProfiles() {
        global $wpdb;

        if(!isset($this->options['status']) || $this->options['status'] != '1') {
            return;
        }

        $data = $this->load_data($this->urls['users']);

        if($data) {
            $wpdb->query('TRUNCATE TABLE ' . DT_PROFILE_IMPORT_IDS);

            foreach($data as $item) {
                $wpdb->replace(
                    DT_PROFILE_IMPORT_IDS,
                    array(
                        'userid' => $item,
                        'network' => 'visit-x',
                        'last_update' => date_i18n("Y-m-d H:i:s")
                    ),
                    array(
                        '%d',
                        '%s',
                        '%s'
                    )
                );
            }

			update_option($this->last_report_setting, __('Crawl von ' . count($data) . ' Profilen erfolgreich abgeschlossen.', 'datingtheme'));
        }

        update_option($this->last_crawl_setting, date_i18n('d.m.Y H:i:s'));
    }

    public function saveProfiles() {
        global $wpdb;

        if(!isset($this->options['status']) || $this->options['status'] != '1') {
            return;
        }

        $filter_gender = '';
        $counter = 0;

        if(!isset($this->options['gender']) || $this->options['gender'] != '') {
            $filter_gender = $this->options['gender'];
        }

        $profiles = $wpdb->get_results( "SELECT * FROM  " . DT_PROFILE_IMPORT_IDS . " WHERE imported = 0 " );
		
        if($profiles) {
            foreach($profiles as $profile) {	
				// break import on limit
				if($counter >= dt_profile_get_import_limit()) {
					break;
				}
																						
				$unique = dt_profile_check_import_status('user_id', $profile->userid);
				// check unique
				if($unique) {
					echo $profile->userid . ' skipped - already imported<br>';
					continue;
				}
				
				// fetch data
				$data = $this->load_data($this->urls['user'], array('user_id' => $profile->userid));
				if(!$data) {
					echo $profile->userid . ' skipped - no data<br>';
					continue;
				}
				
				if($data == 'gone_away') {
					// update table, profile gone away, skip
					$wpdb->update(
						DT_PROFILE_IMPORT_IDS,
						array( 'imported' => 1 ),
						array( 'userid' => $profile->userid ),
						array( '%d' ),
						array( '%d' )
					);
					
					echo $profile->userid . ' skipped - gone_away<br>';

					continue;
				}
				
				if($data == 'wait') {
					break;
				}
				
				// format items
				if($data['gender'] == 'F') {
					$gender = 'female';
				} else if($data['gender'] == 'M') {
					$gender = 'male';
				} else {
					$gender = $data['gender'];
				}

				// filter items
				if($filter_gender) {
					if($gender != $filter_gender) {
						echo $profile->userid . ' skipped - wrong gender<br>';
						continue;
					}
				}
				
				// add post
				$post = new addProfile($data['name'], $data['introduction'], 'user_id', $profile->userid);
				if(!$post) {
					echo $profile->userid . ' skipped - error adding post<br>';
					continue;
				}
				
				if($post->post_id) {
					$post->add_field('user_id', $profile->userid);

					if($data['zip']) {
						$post->add_field('profile_plz', $data['zip']);
					}

					if($data['size']) {
						$post->add_field('profile_size', $data['size']);
					}

					if($data['weight']) {
						$post->add_field('profile_weight', $data['weight']);
					}

					if($data['picture']) {
						$post->add_image($data['picture'], true);
					}

					if($data['figure']) {
						$post->add_field('profile_figure', $data['figure']);
					}

					if($data['hairColor']) {
						$post->add_field('profile_hair_color', $data['hairColor']);
					}

					if($data['birthday']) {
						$age = floor((time() - strtotime($data['birthday'])) / 31556926);

						if($age) {
							$post->add_field('profile_age', $age);
						}
					}

					if($data['gender']) {
						$post->add_field('profile_gender', $gender);
					}

					if($data['characteristics']) {
						$post->add_term('profile_characteristics', $data['characteristics']);
					}

					if($data['sexualPreferences']) {
						$post->add_term('profile_sexual_pref', $data['sexualPreferences']);
					}

					// update table
					$wpdb->update(
						DT_PROFILE_IMPORT_IDS,
						array( 'imported' => 1 ),
						array( 'userid' => $profile->userid ),
						array( '%d' ),
						array( '%d' )
					);

					echo $profile->userid . ' (' . $counter . ') imported successfully<br>';
					
					$counter++;
				}
			}
			
			if($counter > 0)
				update_option($this->last_report_setting, __('Import von ' . $counter . ' Profilen erfolgreich abgeschlossen.', 'datingtheme'));
        }

        update_option($this->last_import_setting, date_i18n('d.m.Y H:i:s'));
    }

    public function removeProfiles() {
        global $wpdb;

        $profiles =  $wpdb->get_results( "
            SELECT wposts.ID, wpostmeta.meta_value
            FROM $wpdb->posts wposts, $wpdb->postmeta wpostmeta
            WHERE wposts.ID = wpostmeta.post_id 
            AND wpostmeta.meta_key = 'user_id' 
            AND wposts.post_type = 'profile'
            AND wposts.post_status = 'publish'
        " );

        if($profiles) {
            foreach($profiles as $item) {
                $post_id = $item->ID;
                $user_id = $item->meta_value;

                $import_id = $wpdb->get_results( 'SELECT ID, userid FROM ' . DT_PROFILE_IMPORT_IDS . ' WHERE userid = ' . $user_id );

                if(!$import_id) {
                    // user not longer exists
                    $args = array(
                        'ID' => $post_id,
                        'post_status' => 'draft'
                    );

                    wp_update_post($args);
                }
            }
        }
    }
}
$profile_crawl = new CrawlProfiles();