<?php
class ImportDashboard {
    private $options;
    private $last_crawl;
    private $last_import;

    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
        add_action( 'admin_notices', array( $this, 'login_notice' ) );
    }

    public function add_plugin_page()
    {
        add_submenu_page(
            'edit.php?post_type=profile',
            'Import',
            'Import',
            'edit_posts',
            'dt-profile-import',
            array( $this, 'create_admin_page' )
        );
    }

    public function create_admin_page()
    {
        $this->options = get_option( 'dt_profile_import' );
        $this->last_crawl = get_option( 'dt_profile_import_last_crawl' );
        $this->last_import = get_option( 'dt_profile_import_last_import' );
        $this->last_report = get_option( 'dt_profile_import_last_report' );
        ?>
        <div class="wrap">
            <h2><?php _e('Import von Profilen', 'datingtheme'); ?></h2>
            <form method="post" action="options.php" style="border-left: 5px solid #d31c13;padding-left:30px;">
                <?php
                settings_fields( 'dt_profile_import_group' );
                do_settings_sections( 'dt-profile-import' );
                submit_button();
                ?>
            </form>

            <h2><?php _e('WordPress Cronjobs', 'datingtheme'); ?></h2>
            <?php
            if($this->last_crawl) {
                echo '<p><strong>' . __('Letzter Crawl:', 'datingtheme') . '</strong> ' . $this->last_crawl . '</p>';
            }

            if($this->last_import) {
                echo '<p><strong>' . __('Letzter Importvorgang:', 'datingtheme') . '</strong> ' . $this->last_import . '</p>';
            }

            if($this->last_report) {
                echo '<p><strong>' . __('Letzte API Meldung:', 'datingtheme') . '</strong> ' . $this->last_report . '</p>';
            }
            ?>

            <p><?php printf(__('Der Importvorgang wird automatisch in regelmäßigen Intervallen (<strong>%s</strong>) ausgeführt, sofern auf deiner Webseite besucher sind. <br>Pro Vorgang werden maximal <strong>%s</strong> Profile importiert.', 'datingtheme'), dt_profile_get_import_interval_label(),  dt_profile_get_import_limit()); ?></p>

            <br>

            <h2><?php _e('Manuelle Cronjobs', 'datingtheme'); ?></h2>
            <p><?php _e('Du kannst die Cronjobs für den Import auch manuell antoßen oder in deinem Hosting-Panel anlegen, nutze dafür die folgenden URLs:', 'datingtheme'); ?></p>
            <p>
                <strong><?php _e('Crawl:', 'datingtheme'); ?></strong> <?php echo admin_url('admin-ajax.php?action=dt_crawl_profiles'); ?>
            </p>
            <p>
                <strong><?php _e('Import:', 'datingtheme'); ?></strong> <?php echo admin_url('admin-ajax.php?action=dt_save_profiles'); ?>
            </p>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {
        register_setting(
            'dt_profile_import_group',
            'dt_profile_import',
            array( $this, 'sanitize' )
        );

        add_settings_section(
            'dt_profile_import_id',
            '',
            '',
            'dt-profile-import'
        );

        add_settings_field(
            'status',
            'Import aktivieren',
            array( $this, 'status_callback' ),
            'dt-profile-import',
            'dt_profile_import_id'
        );

        add_settings_section(
            'dt_profile_import_filter',
            __('Daten filtern', 'datingtheme'),
            '',
            'dt-profile-import'
        );

        add_settings_field(
            'gender',
            __('Geschlecht', 'datingtheme'),
            array( $this, 'gender_callback' ),
            'dt-profile-import',
            'dt_profile_import_filter'
        );
    }

    public function sanitize( $input )
    {
        $new_input = array();
        if( isset( $input['status'] ) )
            $new_input['status'] = $input['status'];

        if( isset( $input['gender'] ) )
            $new_input['gender'] = $input['gender'];

        return $new_input;
    }

    public function print_section_info()
    {
    }

    public function status_callback()
    {
        printf(
            '<input type="checkbox" id="status" name="dt_profile_import[status]" value="1" ' . (isset($this->options['status']) ? checked(1, $this->options['status'], false) : '') .  ' />',
            isset( $this->options['status'] ) ? esc_attr( $this->options['status']) : ''
        );
    }

    public function gender_callback()
    {
        ?>
        <select id="gender" name="dt_profile_import[gender]">
            <option value="" selected><?php _e('Jedes Geschlecht', 'datingtheme'); ?></option>
            <option value="male" <?php echo ((isset( $this->options['gender'] )  && $this->options['gender'] == 'male') ? 'selected' : ''); ?>><?php _e('Männlich', 'datingtheme'); ?></option>
            <option value="female" <?php echo ((isset( $this->options['gender'] )  && $this->options['gender'] == 'female') ? 'selected' : ''); ?>><?php _e('Weiblich', 'datingtheme'); ?></option>
            <option value="T" <?php echo ((isset( $this->options['gender'] )  && $this->options['gender'] == 'T') ? 'selected' : ''); ?>><?php _e('Transvestiten', 'datingtheme'); ?></option>
            <option value="S" <?php echo ((isset( $this->options['gender'] )  && $this->options['gender'] == 'S') ? 'selected' : ''); ?>><?php _e('Shemale/Transsexuelle', 'datingtheme'); ?></option>
            <option value="FF" <?php echo ((isset( $this->options['gender'] )  && $this->options['gender'] == 'FF') ? 'selected' : ''); ?>><?php _e('Paare (Frau/Frau)', 'datingtheme'); ?></option>
            <option value="FM" <?php echo ((isset( $this->options['gender'] )  && $this->options['gender'] == 'FM') ? 'selected' : ''); ?>><?php _e('Paare (Frau/Mann)', 'datingtheme'); ?></option>
            <option value="MM" <?php echo ((isset( $this->options['gender'] )  && $this->options['gender'] == 'MM') ? 'selected' : ''); ?>><?php _e('Paare (Mann/Mann)', 'datingtheme'); ?></option>
        </select>
        <?php
    }


    public function login_notice() {
        if ((isset($_GET['post_type']) && $_GET['post_type'] == 'profile') && (isset($_GET['page']) && $_GET['page'] == 'dt-profile-import')) {

            if( ! ini_get('allow_url_fopen') ) {
                ?>
                <div class="notice notice-error is-dismissible">
                    <p><?php _e('Auf deinem Server ist die Funktion <mark><a href="http://php.net/manual/de/filesystem.configuration.php" target="_blank"">allow_url_fopen</a></mark> nicht aktiviert.<br>Diese Funktion ist für den Import <strong>notwendig</strong>, bitte kontaktiere deinen Hoster.', 'datinghtme'); ?></p>
                </div>
                <?php
            }

            $this->options = get_option( 'dt_profile_import' );
            $wid = get_field('lustagenten_wm_id', 'options');
            $api_key = get_field('lustagenten_api_key', 'options');

            if(!isset($this->options['status']) || $this->options['status'] != '1') {
                return;
            }

            if(!$wid || !$api_key) {
                ?>
                <div class="notice notice-warning">
                    <h3><span class="dashicons dashicons-warning"></span> <?php _e('Achtung', 'datingtheme'); ?></h3>
                    <p><?php _e('Damit der Import funktionieren kann, musst du deine Webmaster ID und deinen API Key in den <a href="' . admin_url('admin.php?page=acf-options-vx-cash') . '">Optionen</a> (Optionen > VX-Cash) ausfüllen.', 'datingtheme'); ?></p>
                </div>
                <?php
            }
        }
    }
}

if( is_admin() ) {
    $profile_import = new ImportDashboard();
}