<?php
/*
 * Shortcodes
 * 
 * @author		Christian Lang
 * @version		1.0
 * @category	locations
 */ 
add_shortcode('profiles', 'dt_profiles_shortcode');
add_shortcode('progessbar', 'dt_progessbar_shortcode');
 
/*
 * Profiles Form
 */
function dt_profiles_shortcode($atts, $content = null) {
    extract(shortcode_atts(array(
        "limit" 			=> "12",
        "gender"            => "",
        "age_from"          => "",
        "age_to"            => "",
        "figure"            => "",
        "hair_color"        => "",
        "weight_from"       => "",
        "weight_to"         => "",
        "size_from"         => "",
        "size_to"           => "",
        "orderby"           => "rand",
        "order"             => "DESC",
        "layout"            => "grid",
        "per_row"              => "6"
    ), $atts));

    $output = '';

    $args = array(
        'post_type'         => 'profile',
        'posts_per_page'    => $limit,
        'orderby'           => $orderby,
        'order'             => $order,
        'meta_query'        => array(
            'relation'      => 'AND'
        ),
    );

    /*
     * Sortierung nach Feld
     */
    if($orderby == 'gender') {
        $args['orderby'] = 'meta_value';
        $args['meta_key'] = 'profile_gender';
    }

    if($orderby == 'age') {
        $args['orderby'] = 'meta_value_num';
        $args['meta_key'] = 'profile_age';
    }

    if($orderby == 'size') {
        $args['orderby'] = 'meta_value_num';
        $args['meta_key'] = 'profile_size';
    }

    if($orderby == 'weight') {
        $args['orderby'] = 'meta_value_num';
        $args['meta_key'] = 'profile_weight';
    }

    /*
     * Geschlecht
     */
    if($gender) {
        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_gender',
                'value'     => $gender
            )
        );
    }

    /*
    * Alter
    */
    if($age_from || $age_to) {
        if($age_from == '') {
            $age_from = '0';
        }

        if($age_to == '') {
            $age_to = '999';
        }

        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_age',
                'value'     => array($age_from, $age_to),
                'compare'   => 'BETWEEN',
                'type'      => 'NUMERIC'
            )
        );
    }

    /*
     * Figur
     */
    if($figure) {
        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_figure',
                'value'     => $figure
            )
        );
    }

    /*
     * Haarfarbe
     */
    if($hair_color) {
        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_hair_color',
                'value'     => $hair_color
            )
        );
    }

    /*
    * Gewicht
    */
    if($weight_from || $weight_to) {
        if($weight_from == '') {
            $weight_from = '0';
        }

        if($weight_to == '') {
            $weight_to = '999';
        }

        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_weight',
                'value'     => array($weight_from, $weight_to),
                'compare'   => 'BETWEEN',
                'type'      => 'NUMERIC'
            )
        );
    }

    /*
    * Größe
    */
    if($size_from || $size_to) {
        if($size_from == '') {
            $size_from = '0';
        }

        if($size_to == '') {
            $size_to = '999';
        }

        $args['meta_query'][] = array(
            array(
                'key'       => 'profile_size',
                'value'     => array($size_from, $size_to),
                'compare'   => 'BETWEEN',
                'type'      => 'NUMERIC'
            )
        );
    }

    global $grid_col;
    $grid_col = $per_row;

    $profiles = new WP_Query($args); if ($profiles->have_posts()) :
        if($layout == 'grid' || $layout == 'grid-small') {
            $output .= '<div class="row">';
        }

        while ($profiles->have_posts()) : $profiles->the_post();
            ob_start();
            get_template_part('parts/profiles/loop', $layout);
            $output .= ob_get_contents();
            ob_end_clean();
        endwhile;

        if($layout == 'grid' || $layout == 'grid-small') {
            $output .= '</div>';
        }

        wp_reset_postdata();
    endif;

	return $output;
}

/*
 * Progress Bars
 */
function dt_progessbar_shortcode($atts, $content = null) {
    extract(shortcode_atts(array(
        "width" 			=> "90",
        "class" 		    => "success",
    ), $atts));

    $output = '
    <div class="progress">
        <div class="progress-bar progress-bar-success" role="progressbar" aria-valuenow="' . $width . '" aria-valuemin="0" aria-valuemax="100" style="width: ' . $width . '%">
            <span class="sr-only">' . $width . '%</span>
        </div>
    </div>
    ';

    return $output;
}